@@ -1,5 +1,5 @@
 /*
-    Convience dialog for displaying PersonDetailsView widgets
+    Convenience dialog for displaying PersonDetailsView widgets
     SPDX-FileCopyrightText: 2013 David Edmundson <davidedmundson@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
@@ -52,3 +52,5 @@ void PersonDetailsDialog::setPerson(PersonData *person)
 
     setWindowTitle(person->name());
 }
+
+#include "moc_persondetailsdialog.cpp"
